==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/outputs/DataTransferServiceResourcePropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Properties for DataTransferServiceResource.
 * @property creationTime Time of the last state change (ISO-8601 format).
 * @property instanceCount Instance count for the service.
 * @property instanceSize Instance type for the service.
 * @property locations An array that contains all of the locations for the service.
 * @property serviceType ServiceType for the service.
 * Expected value is 'DataTransfer'.
 * @property status Describes the status of a service.
 */
public data class DataTransferServiceResourcePropertiesResponse(
    public val creationTime: String,
    public val instanceCount: Int? = null,
    public val instanceSize: String? = null,
    public val locations: List<DataTransferRegionalServiceResourceResponse>,
    public val serviceType: String,
    public val status: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.documentdb.outputs.DataTransferServiceResourcePropertiesResponse):
            DataTransferServiceResourcePropertiesResponse =
            DataTransferServiceResourcePropertiesResponse(
                creationTime = javaType.creationTime(),
                instanceCount = javaType.instanceCount().map({ args0 -> args0 }).orElse(null),
                instanceSize = javaType.instanceSize().map({ args0 -> args0 }).orElse(null),
                locations = javaType.locations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.documentdb.kotlin.outputs.DataTransferRegionalServiceResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                serviceType = javaType.serviceType(),
                status = javaType.status(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/outputs/DataTransferServiceResourcePropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Properties for DataTransferServiceResource.
 * @property creationTime Time of the last state change (ISO-8601 format).
 * @property instanceCount Instance count for the service.
 * @property instanceSize Instance type for the service.
 * @property locations An array that contains all of the locations for the service.
 * @property serviceType ServiceType for the service.
 * Expected value is 'DataTransfer'.
 * @property status Describes the status of a service.
 */
public data class DataTransferServiceResourcePropertiesResponse(
    public val creationTime: String,
    public val instanceCount: Int? = null,
    public val instanceSize: String? = null,
    public val locations: List<DataTransferRegionalServiceResourceResponse>,
    public val serviceType: String,
    public val status: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.documentdb.outputs.DataTransferServiceResourcePropertiesResponse): DataTransferServiceResourcePropertiesResponse =
            DataTransferServiceResourcePropertiesResponse(
                creationTime = javaType.creationTime(),
                instanceCount = javaType.instanceCount().map({ args0 -> args0 }).orElse(null),
                instanceSize = javaType.instanceSize().map({ args0 -> args0 }).orElse(null),
                locations = javaType.locations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.documentdb.kotlin.outputs.DataTransferRegionalServiceResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                serviceType = javaType.serviceType(),
                status = javaType.status(),
            )
    }
}
